@@ -2,9 +2,8 @@
 # License: GPLv3 Copyright: 2008, Kovid Goyal <kovid at kovidgoyal.net>
 
 
-from enum import IntEnum
 import textwrap
-
+from enum import IntEnum
 from qt.core import (
     QAction, QApplication, QBrush, QCheckBox, QDialog, QDialogButtonBox, QGridLayout,
     QHBoxLayout, QIcon, QKeySequence, QLabel, QListView, QModelIndex, QPalette, QPixmap,
@@ -13,6 +12,7 @@ from qt.core import (
 )
 
 from calibre import fit_image
+from calibre.db.constants import RESOURCE_URL_SCHEME
 from calibre.gui2 import NO_URL_FORMATTING, gprefs
 from calibre.gui2.book_details import (
     create_open_cover_with_menu, resolved_css, details_context_menu_event, render_html, set_html,
@@ -119,6 +119,8 @@ class Configure(Dialog):
 
 class Details(HTMLDisplay):
 
+    notes_resource_scheme = RESOURCE_URL_SCHEME
+
     def __init__(self, book_info, parent=None, allow_context_menu=True, is_locked=False):
         HTMLDisplay.__init__(self, parent)
         self.book_info = book_info
@@ -127,6 +129,9 @@ class Details(HTMLDisplay):
         self.allow_context_menu = allow_context_menu
         self.is_locked = is_locked
 
+    def get_base_qurl(self):
+        return getattr(self.book_info, 'base_url_for_current_book', None)
+
     def sizeHint(self):
         return QSize(350, 350)
 
@@ -301,7 +306,7 @@ class BookInfo(QDialog):
 
     def on_link_clicked(self, qurl):
         link = str(qurl.toString(NO_URL_FORMATTING))
-        self.link_delegate(link)
+        self.link_delegate(link, self)
 
     def done(self, r):
         self.save_geometry(gprefs, self.geometry_string('book_info_dialog_geometry'))
@@ -417,7 +422,7 @@ class BookInfo(QDialog):
         self.cover_pixmap.setDevicePixelRatio(dpr)
         self.marked = mi.marked
         self.resize_cover()
-        html = render_html(mi, True, self, pref_name='popup_book_display_fields')
+        html = render_html(mi, True, self, pref_name='popup_book_display_fields')[0]
         set_html(mi, html, self.details)
         self.update_cover_tooltip()
 
