@@ -7,11 +7,12 @@ import posixpath
 from contextlib import contextmanager
 from datetime import datetime
 from functools import partial
+from math import ceil
 from qt.core import (
     QAbstractItemView, QAbstractListModel, QComboBox, QCursor, QDialogButtonBox,
     QHBoxLayout, QIcon, QItemSelection, QItemSelectionModel, QLabel, QListView, QMenu,
     QPushButton, QRect, QSize, QStyle, QStyledItemDelegate, Qt, QTextDocument, QTimer,
-    QVBoxLayout, pyqtSignal, sip,
+    QVBoxLayout, pyqtSignal, sip, QDropEvent
 )
 
 from calibre import human_readable, prepare_string_for_xml
@@ -75,7 +76,7 @@ class Delegate(QStyledItemDelegate):
         if self.doc_size is None:
             d = self.doc_for_index(index)
             self.doc_size = d.size()
-        ans.setHeight(max(self.doc_size.height() + 2, ans.height()))
+        ans.setHeight(max(int(ceil(self.doc_size.height()) + 2), ans.height()))
         return ans
 
     def paint(self, painter, option, index):
@@ -168,6 +169,41 @@ class Files(QAbstractListModel):
         return Qt.ItemFlag.ItemIsSelectable | Qt.ItemFlag.ItemIsEnabled | Qt.ItemFlag.ItemIsEditable
 
 
+class ListView(QListView):
+
+    files_dropped = pyqtSignal(object)
+
+    def __init__(self, parent=None):
+        super().__init__(parent)
+        self.setAcceptDrops(True)
+
+    def is_drop_event_ok(self, ev: QDropEvent):
+        if ev.proposedAction() in (Qt.DropAction.CopyAction, Qt.DropAction.MoveAction, Qt.DropAction.TargetMoveAction):
+            md = ev.mimeData()
+            if md.hasUrls():
+                for url in md.urls():
+                    if url.isLocalFile() and os.access(url.toLocalFile(), os.R_OK):
+                        return True
+        return False
+
+    def dragEnterEvent(self, ev: QDropEvent):
+        if self.is_drop_event_ok(ev):
+            ev.accept()
+
+    def dragMoveEvent(self, ev: QDropEvent):
+        ev.accept()
+
+    def dropEvent(self, ev):
+        files = []
+        if self.is_drop_event_ok(ev):
+            md = ev.mimeData()
+            for url in md.urls():
+                if url.isLocalFile() and os.access(url.toLocalFile(), os.R_OK):
+                    files.append(url.toLocalFile())
+        if files:
+            self.files_dropped.emit(files)
+
+
 class DataFilesManager(Dialog):
 
     def __init__(self, db, book_id, parent=None):
@@ -196,7 +232,8 @@ class DataFilesManager(Dialog):
 
         self.delegate = d = Delegate(self)
         d.rename_requested.connect(self.rename_requested, type=Qt.ConnectionType.QueuedConnection)
-        self.fview = v = QListView(self)
+        self.fview = v = ListView(self)
+        v.files_dropped.connect(self.do_add_files)
         v.setContextMenuPolicy(Qt.ContextMenuPolicy.CustomContextMenu)
         v.customContextMenuRequested.connect(self.context_menu)
         set_no_activate_on_click(v)
@@ -213,11 +250,18 @@ class DataFilesManager(Dialog):
         v.selectionModel().currentChanged.connect(self.current_changed)
 
         self.current_label = la = QLabel(self)
-        la.setOpenExternalLinks(False)
-        la.linkActivated.connect(self.open_with, type=Qt.ConnectionType.QueuedConnection)
-        la.setTextFormat(Qt.TextFormat.RichText)
         la.setWordWrap(True)
-        l.addWidget(la)
+        la.setTextFormat(Qt.TextFormat.PlainText)
+        self.clah = h = QHBoxLayout()
+        l.addLayout(h)
+        h.addWidget(la, stretch=100)
+        h.addSpacing(4)
+        self.open_with_label = la = QLabel('<a style="text-decoration:none" href="open_with://current">{}</a>'.format(_('Open with')))
+        la.setOpenExternalLinks(False)
+        la.setTextFormat(Qt.TextFormat.RichText)
+        la.linkActivated.connect(self.open_with, type=Qt.ConnectionType.QueuedConnection)
+        la.setVisible(False)
+        h.addWidget(la)
 
         l.addWidget(self.bb)
         self.add_button = b = QPushButton(QIcon.ic('plus.png'), _('&Add files'), self)
@@ -253,7 +297,7 @@ class DataFilesManager(Dialog):
         m.exec(self.fview.mapToGlobal(pos))
 
     def keyPressEvent(self, ev):
-        if ev.key() == Qt.Key.Key_Return:
+        if ev.key() in (Qt.Key.Key_Return, Qt.Key.Key_Enter):
             return
         return super().keyPressEvent(ev)
 
@@ -270,9 +314,11 @@ class DataFilesManager(Dialog):
             txt = self.files.file_display_name(idx.row())
         txt = prepare_string_for_xml(txt)
         if txt:
-            self.current_label.setText('<p>{} <a href="open_with://{}">{}</a>'.format(txt, idx.row(), prepare_string_for_xml(_('Open with'))))
+            self.current_label.setText(txt)
+            self.open_with_label.setVisible(True)
         else:
-            self.current_label.setText('')
+            self.current_label.setText('\xa0')
+            self.open_with_label.setVisible(False)
 
     def open_with_menu(self, file_path):
         m = QMenu(_('Open with...'), parent=self)
@@ -346,6 +392,9 @@ class DataFilesManager(Dialog):
         files = choose_files(self, 'choose-data-files-to-add', _('Choose files to add'))
         if not files:
             return
+        self.do_add_files(files)
+
+    def do_add_files(self, files):
         q = self.db.are_paths_inside_book_dir(self.book_id, files, DATA_DIR_NAME)
         if q:
             return error_dialog(
