@@ -32,7 +32,9 @@ from calibre.gui2.custom_column_widgets import get_field_list as em_get_field_li
 from calibre.gui2.dialogs.quickview import get_qv_field_list
 from calibre.gui2.dialogs.template_dialog import TemplateDialog
 from calibre.gui2.library.alternate_views import CM_TO_INCH, auto_height
-from calibre.gui2.preferences import ConfigWidgetBase, Setting, test_widget
+from calibre.gui2.preferences import (
+    ConfigWidgetBase, Setting, set_help_tips, test_widget,
+)
 from calibre.gui2.preferences.coloring import EditRules
 from calibre.gui2.preferences.look_feel_ui import Ui_Form
 from calibre.gui2.widgets import BusyCursor
@@ -578,7 +580,6 @@ class ConfigWidget(ConfigWidgetBase, Ui_Form):
         self.default_author_link = DefaultAuthorLink(self.default_author_link_container)
         self.default_author_link.changed_signal.connect(self.changed_signal)
         r('ui_style', gprefs, restart_required=True, choices=[(_('System default'), 'system'), (_('calibre style'), 'calibre')])
-        r('color_palette', gprefs, restart_required=True, choices=[(_('System default'), 'system'), (_('Light'), 'light'), (_('Dark'), 'dark')])
         r('book_list_tooltips', gprefs)
         r('dnd_merge', gprefs)
         r('wrap_toolbar_text', gprefs, restart_required=True)
@@ -608,6 +609,10 @@ class ConfigWidget(ConfigWidgetBase, Ui_Form):
 
         r('cover_flow_queue_length', config, restart_required=True)
         r('cover_browser_reflections', gprefs)
+        r('cover_browser_narrow_view_position', gprefs,
+                            choices=[(_('Automatic'), 'automatic'), # Automatic must be first
+                                     (_('On top'), 'on_top'),
+                                     (_('On right'), 'on_right')])
         r('cover_browser_title_template', db.prefs)
         fm = db.field_metadata
         r('cover_browser_subtitle_field', db.prefs, choices=[(_('No subtitle'), 'none')] + sorted(
@@ -833,6 +838,15 @@ class ConfigWidget(ConfigWidgetBase, Ui_Form):
         self.opt_gui_layout.addItem(_('Wide'), 'wide')
         self.opt_gui_layout.addItem(_('Narrow'), 'narrow')
         self.opt_gui_layout.currentIndexChanged.connect(self.changed_signal)
+        set_help_tips(self.opt_gui_layout, config.help('gui_layout'))
+        self.button_adjust_colors.clicked.connect(self.adjust_colors)
+
+    def adjust_colors(self):
+        from calibre.gui2.dialogs.palette import PaletteConfig
+        d = PaletteConfig(self)
+        if d.exec() == QDialog.DialogCode.Accepted:
+            d.apply_settings()
+            self.changed_signal.emit()
 
     def initial_tab_changed(self):
         self.sections_view.setCurrentRow(self.tabWidget.currentIndex())
@@ -900,8 +914,7 @@ class ConfigWidget(ConfigWidgetBase, Ui_Form):
     def update_color_palette_state(self):
         if self.ui_style_available:
             enabled = self.opt_ui_style.currentData() == 'calibre'
-            self.opt_color_palette.setEnabled(enabled)
-            self.opt_color_palette_label.setEnabled(enabled)
+            self.button_adjust_colors.setEnabled(enabled)
 
     def export_layout(self, model=None):
         filename = choose_save_file(self, 'em_import_export_field_list',
@@ -1041,6 +1054,12 @@ class ConfigWidget(ConfigWidgetBase, Ui_Form):
         self.tb_focus_label.setVisible(self.opt_tag_browser_allow_keyboard_focus.isChecked())
         self.update_color_palette_state()
         self.opt_gui_layout.setCurrentIndex(0 if self.gui.layout_container.is_wide else 1)
+        set_help_tips(self.opt_cover_browser_narrow_view_position, _(
+            'This option controls the position of the cover browser when using the Narrow user '
+            'interface layout.  "Automatic" will place the cover browser on top or on the right '
+            'of the book list depending on the aspect ratio of the calibre window. "On top" '
+            'places it over the book list, and "On right" places it to the right of the book '
+            'list. This option has no effect when using the Wide user interface layout.'))
 
     def open_cg_cache(self):
         open_local_file(self.gui.grid_view.thumbnail_cache.location)
