@@ -4,6 +4,7 @@
 import errno
 import os
 import shutil
+import subprocess
 import sys
 import tempfile
 from functools import partial, wraps
@@ -14,7 +15,7 @@ from qt.core import (
 )
 
 from calibre import isbytestring, prints
-from calibre.constants import cache_dir, iswindows
+from calibre.constants import cache_dir, islinux, ismacos, iswindows
 from calibre.ebooks.oeb.base import urlnormalize
 from calibre.ebooks.oeb.polish.container import (
     OEB_DOCS, OEB_STYLES, clone_container, get_container as _gc, guess_type,
@@ -35,7 +36,7 @@ from calibre.ebooks.oeb.polish.utils import (
 )
 from calibre.gui2 import (
     add_to_recent_docs, choose_dir, choose_files, choose_save_file, error_dialog,
-    info_dialog, open_url, question_dialog, warning_dialog,
+    info_dialog, open_url, question_dialog, sanitize_env_vars, warning_dialog,
 )
 from calibre.gui2.dialogs.confirm_delete import confirm
 from calibre.gui2.tweak_book import (
@@ -65,6 +66,7 @@ from calibre.startup import connect_lambda
 from calibre.utils.config import JSONConfig
 from calibre.utils.icu import numeric_sort_key
 from calibre.utils.imghdr import identify
+from calibre.utils.ipc.launch import exe_path, macos_edit_book_bundle_path
 from calibre.utils.localization import ngettext
 from calibre.utils.tdir_in_cache import tdir_in_cache
 from polyglot.builtins import as_bytes, iteritems, itervalues, string_or_bytes
@@ -354,6 +356,7 @@ class Boss(QObject):
         self._edit_file_on_open = self._search_text_on_open = None
 
         if job.traceback is not None:
+            self.gui.update_status_bar_default_message()
             if 'DRMError:' in job.traceback:
                 from calibre.gui2.dialogs.drm_error import DRMErrorMessage
                 return DRMErrorMessage(self.gui).exec()
@@ -388,6 +391,7 @@ class Boss(QObject):
             path = os.path.abspath(container.path_to_ebook)
             if path in recent_books:
                 recent_books.remove(path)
+            self.gui.update_status_bar_default_message(path)
             recent_books.insert(0, path)
             tprefs['recent-books'] = recent_books[:10]
             self.gui.update_recent_books()
@@ -870,11 +874,11 @@ class Boss(QObject):
                     editor = editors[name]
                     editor.go_to_line(lnum)
                     editor.setFocus(Qt.FocusReason.OtherFocusReason)
-                    self.gui.raise_()
+                    self.gui.raise_and_focus()
         d = Diff(revert_button_msg=revert_msg, show_open_in_editor=show_open_in_editor)
         [x.break_cycles() for x in _diff_dialogs if not x.isVisible()]
         _diff_dialogs = [x for x in _diff_dialogs if x.isVisible()] + [d]
-        d.show(), d.raise_(), d.setFocus(Qt.FocusReason.OtherFocusReason), d.setWindowModality(Qt.WindowModality.NonModal)
+        d.show(), d.raise_and_focus(), d.setFocus(Qt.FocusReason.OtherFocusReason), d.setWindowModality(Qt.WindowModality.NonModal)
         if show_open_in_editor:
             d.line_activated.connect(line_activated)
         return d
@@ -1312,7 +1316,7 @@ class Boss(QObject):
         container = clone_container(c, tdir)
         self.save_manager.schedule(tdir, container)
 
-    def save_copy(self):
+    def _save_copy(self, post_action=None):
         self.gui.update_window_title()
         c = current_container()
         if c.is_dir:
@@ -1338,14 +1342,34 @@ class Boss(QObject):
             shutil.rmtree(tdir, ignore_errors=True)
             return path
 
-        self.gui.blocking_job('save_copy', _('Saving copy, please wait...'), self.copy_saved, do_save, container, path, tdir)
+        self.gui.blocking_job('save_copy', _('Saving copy, please wait...'), partial(self.copy_saved, post_action=post_action), do_save, container, path, tdir)
 
-    def copy_saved(self, job):
+    def save_copy(self):
+        self._save_copy()
+
+    def copy_saved(self, job, post_action=None):
         if job.traceback is not None:
             return error_dialog(self.gui, _('Failed to save copy'),
                     _('Failed to save copy, click "Show details" for more information.'), det_msg=job.traceback, show=True)
         msg = _('Copy saved to %s') % job.result
-        info_dialog(self.gui, _('Copy saved'), msg, show=True)
+        if post_action is None:
+            info_dialog(self.gui, _('Copy saved'), msg, show=True)
+        elif post_action == 'replace':
+            msg = _('Editing saved copy at: %s') % job.result
+            self.open_book(job.result, edit_file=self.currently_editing)
+        elif post_action == 'edit':
+            if ismacos:
+                cmd = ['open', '-F', '-n', '-a', os.path.dirname(os.path.dirname(os.path.dirname(macos_edit_book_bundle_path()))), '--args']
+            else:
+                cmd = [exe_path('ebook-edit')]
+                if islinux:
+                    cmd.append('--detach')
+            cmd.append(job.result)
+            ce = self.currently_editing
+            if ce:
+                cmd.append(ce)
+            with sanitize_env_vars():
+                subprocess.Popen(cmd)
         self.gui.show_status_message(msg, 5)
 
     def report_save_error(self, tb):
@@ -1460,7 +1484,7 @@ class Boss(QObject):
         self.commit_all_editors_to_container()
         c = self.gui.check_book
         c.parent().show()
-        c.parent().raise_()
+        c.parent().raise_and_focus()
         c.run_checks(current_container())
 
     def spell_check_requested(self):
@@ -1475,7 +1499,7 @@ class Boss(QObject):
         self.add_savepoint(_('Before: Auto-fix errors'))
         c = self.gui.check_book
         c.parent().show()
-        c.parent().raise_()
+        c.parent().raise_and_focus()
         changed = c.fix_errors(current_container(), errors)
         if changed:
             self.apply_container_update_to_gui()
@@ -1588,14 +1612,14 @@ class Boss(QObject):
     def browse_images(self):
         self.gui.image_browser.refresh()
         self.gui.image_browser.show()
-        self.gui.image_browser.raise_()
+        self.gui.image_browser.raise_and_focus()
 
     def show_reports(self):
         if not self.ensure_book(_('You must first open a book in order to see the report.')):
             return
         self.gui.reports.refresh()
         self.gui.reports.show()
-        self.gui.reports.raise_()
+        self.gui.reports.raise_and_focus()
 
     def reports_edit_requested(self, name):
         mt = current_container().mime_map.get(name, guess_type(name))
@@ -1887,6 +1911,9 @@ class Boss(QObject):
         from calibre.gui2.tweak_book.editor.snippets import UserSnippets
         UserSnippets(self.gui).exec()
 
+    def merge_files(self):
+        self.gui.file_list.merge_files()
+
     # Shutdown {{{
 
     def quit(self):
