@@ -98,7 +98,7 @@ def get_bulk_rename_settings(parent, number, msg=None, sanitize=sanitize_file_na
     l.addRow(la)
     l.addRow(_('&Prefix:'), p)
     d.num = num = QSpinBox(d)
-    num.setMinimum(0), num.setValue(1), num.setMaximum(1000)
+    num.setMinimum(0), num.setValue(1), num.setMaximum(10000)
     l.addRow(_('Starting &number:'), num)
     if allow_spine_order:
         d.spine_order = QCheckBox(_('Rename files according to their book order'))
@@ -766,6 +766,22 @@ class FileList(QTreeWidget, OpenWithHandler):
                     return (category, i)
         return (None, -1)
 
+    def merge_files(self):
+        sel = self.selectedItems()
+        selected_map = defaultdict(list)
+        for item in sel:
+            selected_map[str(item.data(0, CATEGORY_ROLE) or '')].append(str(item.data(0, NAME_ROLE) or ''))
+
+        for items in selected_map.values():
+            items.sort(key=self.index_of_name)
+        if len(selected_map['text']) > 1:
+            self.start_merge('text', selected_map['text'])
+        elif len(selected_map['styles']) > 1:
+            self.start_merge('styles', selected_map['styles'])
+        else:
+            error_dialog(self, _('Cannot merge'), _(
+                'No files selected. Select two or more HTML files or two or more CSS files in the Files browser before trying to merge'), show=True)
+
     def start_merge(self, category, names):
         d = MergeDialog(names, self)
         if d.exec() == QDialog.DialogCode.Accepted and d.ans:
@@ -876,6 +892,16 @@ class FileList(QTreeWidget, OpenWithHandler):
         ans.discard('')
         return ans
 
+    @property
+    def selected_names_in_order(self):
+        root = self.invisibleRootItem()
+        for category_item in (root.child(i) for i in range(root.childCount())):
+            for child in (category_item.child(i) for i in range(category_item.childCount())):
+                if child.isSelected():
+                    name = child.data(0, NAME_ROLE)
+                    if name:
+                        yield name
+
     def move_selected_text_items(self, amt: int) -> bool:
         parent = self.categories['text']
         children = tuple(parent.child(i) for i in range(parent.childCount()))
@@ -906,7 +932,7 @@ class FileList(QTreeWidget, OpenWithHandler):
         return changed
 
     def copy_selected_files(self):
-        self.initiate_file_copy.emit(self.selected_names)
+        self.initiate_file_copy.emit(tuple(self.selected_names_in_order))
 
     def paste_from_other_instance(self):
         self.initiate_file_paste.emit()
@@ -1254,6 +1280,9 @@ class FileListWidget(QWidget):
     def restore_temp_names(self):
         self.file_list.restore_temp_names()
 
+    def merge_files(self):
+        self.file_list.merge_files()
+
     @property
     def searchable_names(self):
         return self.file_list.searchable_names
