@@ -30,10 +30,9 @@ from calibre.constants import (
 from calibre.customize import PluginInstallationType
 from calibre.customize.ui import available_store_plugins, interface_actions
 from calibre.db.legacy import LibraryDatabase
-from calibre.gui2.extra_files_watcher import ExtraFilesWatcher
 from calibre.gui2 import (
     Dispatcher, GetMetadata, config, error_dialog, gprefs, info_dialog,
-    max_available_height, open_url, question_dialog, warning_dialog,
+    max_available_height, open_url, question_dialog, timed_print, warning_dialog,
 )
 from calibre.gui2.auto_add import AutoAdder
 from calibre.gui2.changes import handle_changes
@@ -42,6 +41,7 @@ from calibre.gui2.device import DeviceMixin
 from calibre.gui2.dialogs.message_box import JobError
 from calibre.gui2.ebook_download import EbookDownloadMixin
 from calibre.gui2.email import EmailMixin
+from calibre.gui2.extra_files_watcher import ExtraFilesWatcher
 from calibre.gui2.init import LayoutMixin, LibraryViewMixin
 from calibre.gui2.job_indicator import Pointer
 from calibre.gui2.jobs import JobManager, JobsButton, JobsDialog
@@ -55,7 +55,7 @@ from calibre.gui2.search_box import SavedSearchBoxMixin, SearchBoxMixin
 from calibre.gui2.search_restriction_mixin import SearchRestrictionMixin
 from calibre.gui2.tag_browser.ui import TagBrowserMixin
 from calibre.gui2.update import UpdateMixin
-from calibre.gui2.widgets import ProgressIndicator
+from calibre.gui2.widgets import ProgressIndicator, BusyCursor
 from calibre.library import current_library_name
 from calibre.srv.library_broker import GuiLibraryBroker, db_matches
 from calibre.utils.config import dynamic, prefs
@@ -118,6 +118,7 @@ class Main(MainWindow, MainWindowMixin, DeviceMixin, EmailMixin,  # {{{
 
     def __init__(self, opts, parent=None, gui_debug=None):
         MainWindow.__init__(self, opts, parent=parent, disable_automatic_gc=True)
+        self.setVisible(False)
         self.setWindowIcon(QApplication.instance().windowIcon())
         self.extra_files_watcher = ExtraFilesWatcher(self)
         self.jobs_pointer = Pointer(self)
@@ -372,7 +373,7 @@ class Main(MainWindow, MainWindowMixin, DeviceMixin, EmailMixin,  # {{{
 
         # ########################## Cover Flow ################################
 
-        CoverFlowMixin.init_cover_flow_mixin(self)
+        CoverFlowMixin.__init__(self)
 
         self._calculated_available_height = min(max_available_height()-15,
                 self.height())
@@ -391,15 +392,25 @@ class Main(MainWindow, MainWindowMixin, DeviceMixin, EmailMixin,  # {{{
 
         if config['autolaunch_server']:
             self.start_content_server()
-
-        if show_gui:
-            self.show()
+        do_hide_windows = False
+        if self.system_tray_icon is not None and self.system_tray_icon.isVisible() and opts.start_in_tray:
+            do_hide_windows = True
+            show_gui = False
+            setattr(self, '__systray_minimized', True)
+        if do_hide_windows:
+            self.hide_windows()
+        self.layout_container.relayout()
+        QTimer.singleShot(0, self.post_initialize_actions)
         self.read_settings()
 
         self.finalize_layout()
         self.bars_manager.start_animation()
         self.set_window_title()
 
+        if show_gui:
+            timed_print('GUI main window shown')
+            self.show()
+
         for ac in self.iactions.values():
             try:
                 ac.initialization_complete()
@@ -413,42 +424,26 @@ class Main(MainWindow, MainWindowMixin, DeviceMixin, EmailMixin,  # {{{
 
         register_keyboard_shortcuts()
         self.keyboard.finalize()
-        if self.system_tray_icon is not None and self.system_tray_icon.isVisible() and opts.start_in_tray:
-            self.hide_windows()
         self.auto_adder = AutoAdder(gprefs['auto_add_path'], self)
 
         self.listener = Listener(parent=self)
         self.listener.message_received.connect(self.message_from_another_instance)
-        QTimer.singleShot(0, self.listener.start_listening)
-
-        # Collect cycles now
-        gc.collect()
 
         QApplication.instance().shutdown_signal_received.connect(self.quit)
         if show_gui and self.gui_debug is not None:
             QTimer.singleShot(10, self.show_gui_debug_msg)
 
         self.iactions['Connect Share'].check_smartdevice_menus()
-        QTimer.singleShot(1, self.start_smartdevice)
         QTimer.singleShot(100, self.update_toggle_to_tray_action)
 
-        # Once the gui is initialized we can restore the quickview state
-        # The same thing will be true for any action-based operation with a
-        # layout button. We need to let a book be selected in the book list
-        # before initializing quickview, so run it after an event loop tick
-        QTimer.singleShot(0, self.start_quickview)
-        # Force repaint of the book details splitter because it otherwise ends
-        # up with the wrong size. I don't know why.
-        QTimer.singleShot(0, self.bd_splitter.repaint)
-
-    def start_quickview(self):
-        from calibre.gui2.actions.show_quickview import get_quickview_action_plugin
-        qv = get_quickview_action_plugin()
-        if qv:
-            if DEBUG:
-                prints('Starting QuickView')
-            qv.qv_button.restore_state()
-        self.save_layout_state()
+    def post_initialize_actions(self):
+        # Various post-initialization actions after an event loop tick
+        if self.layout_container.is_visible.quick_view:
+            self.iactions['Quickview'].show_on_startup()
+        self.listener.start_listening()
+        self.start_smartdevice()
+        # Collect cycles now
+        gc.collect()
         self.focus_library_view()
 
     def show_gui_debug_msg(self):
@@ -479,13 +474,16 @@ class Main(MainWindow, MainWindowMixin, DeviceMixin, EmailMixin,  # {{{
     def start_smartdevice(self):
         message = None
         if self.device_manager.get_option('smartdevice', 'autostart'):
-            try:
-                message = self.device_manager.start_plugin('smartdevice')
-            except:
-                message = 'start smartdevice unknown exception'
-                prints(message)
-                import traceback
-                traceback.print_exc()
+            timed_print('Starting the smartdevice driver')
+            with BusyCursor():
+                try:
+                    message = self.device_manager.start_plugin('smartdevice')
+                    timed_print('Finished starting smartdevice')
+                except Exception as e:
+                    message = str(e)
+                    timed_print(f'Starting smartdevice driver failed: {message}')
+                    import traceback
+                    traceback.print_exc()
         if message:
             if not self.device_manager.is_running('Wireless Devices'):
                 error_dialog(self, _('Problem starting the wireless device'),
@@ -859,7 +857,7 @@ class Main(MainWindow, MainWindowMixin, DeviceMixin, EmailMixin,  # {{{
                 self.handle_cli_args(argv[1:])
             self.setWindowState(self.windowState() & ~Qt.WindowState.WindowMinimized|Qt.WindowState.WindowActive)
             self.show_windows()
-            self.raise_()
+            self.raise_and_focus()
             self.activateWindow()
         elif msg.startswith('shutdown:'):
             self.quit(confirm_quit=False)
@@ -1023,9 +1021,8 @@ class Main(MainWindow, MainWindowMixin, DeviceMixin, EmailMixin,  # {{{
         page = 0 if location == 'library' else 1 if location == 'main' else 2 if location == 'carda' else 3
         self.stack.setCurrentIndex(page)
         self.book_details.reset_info()
-        for x in ('tb', 'cb'):
-            splitter = getattr(self, x+'_splitter')
-            splitter.button.setEnabled(location == 'library')
+        self.layout_container.tag_browser_button.setEnabled(location == 'library')
+        self.layout_container.cover_browser_button.setEnabled(location == 'library')
         for action in self.iactions.values():
             action.location_selected(location)
         if location == 'library':
@@ -1148,7 +1145,7 @@ class Main(MainWindow, MainWindowMixin, DeviceMixin, EmailMixin,  # {{{
             self.save_geometry(gprefs, 'calibre_main_window_geometry')
             dynamic.set('sort_history', self.library_view.model().sort_history)
             self.save_layout_state()
-            self.stack.tb_widget.save_state()
+            self.tb_widget.save_state()
 
     def quit(self, checked=True, restart=False, debug_on_restart=False,
             confirm_quit=True, no_plugins_on_restart=False):
