@@ -6,11 +6,11 @@ Miscellaneous widgets used in the GUI
 import os
 import re
 from qt.core import (
-    QAction, QApplication, QClipboard, QColor, QComboBox, QCompleter, QCursor, QEvent,
-    QFont, QGraphicsScene, QGraphicsView, QIcon, QKeySequence, QLabel, QLineEdit,
-    QListWidget, QListWidgetItem, QMenu, QPageSize, QPainter, QPalette, QPen, QPixmap,
-    QPrinter, QRect, QSize, QSplitter, QSplitterHandle, QStringListModel,
-    QSyntaxHighlighter, Qt, QTextCharFormat, QTimer, QToolButton, QWidget, pyqtSignal,
+    QApplication, QClipboard, QColor, QComboBox, QCompleter, QCursor, QEvent, QFont,
+    QGraphicsScene, QGraphicsView, QIcon, QLabel, QLineEdit, QListWidget,
+    QListWidgetItem, QMenu, QPageSize, QPainter, QPalette, QPen, QPixmap, QPrinter,
+    QRect, QSize, QSplitterHandle, QStringListModel, QSyntaxHighlighter, Qt,
+    QTextCharFormat, QWidget, pyqtSignal,
 )
 
 from calibre import fit_image, force_unicode, strftime
@@ -1063,267 +1063,6 @@ class SplitterHandle(QSplitterHandle):
         self.double_clicked.emit(self)
 
 
-class LayoutButton(QToolButton):
-
-    def __init__(self, icon, text, splitter=None, parent=None, shortcut=None):
-        QToolButton.__init__(self, parent)
-        self.label = text
-        self.setIcon(QIcon.ic(icon))
-        self.setCheckable(True)
-        self.icname = os.path.basename(icon).rpartition('.')[0]
-
-        self.splitter = splitter
-        if splitter is not None:
-            splitter.state_changed.connect(self.update_state)
-        self.setCursor(Qt.CursorShape.PointingHandCursor)
-        self.shortcut = shortcut or ''
-
-    def update_shortcut(self, action_toggle=None):
-        action_toggle = action_toggle or getattr(self, 'action_toggle', None)
-        if action_toggle:
-            sc = ', '.join(sc.toString(QKeySequence.SequenceFormat.NativeText)
-                                for sc in action_toggle.shortcuts())
-            self.shortcut = sc or ''
-            self.update_text()
-
-    def update_text(self):
-        t = _('Hide {}') if self.isChecked() else _('Show {}')
-        t = t.format(self.label)
-        if self.shortcut:
-            t += f' [{self.shortcut}]'
-        self.setText(t), self.setToolTip(t), self.setStatusTip(t)
-
-    def set_state_to_show(self, *args):
-        self.setChecked(False)
-        self.update_text()
-
-    def set_state_to_hide(self, *args):
-        self.setChecked(True)
-        self.update_text()
-
-    def update_state(self, *args):
-        if self.splitter.is_side_index_hidden:
-            self.set_state_to_show()
-        else:
-            self.set_state_to_hide()
-
-    def mouseReleaseEvent(self, ev):
-        if ev.button() == Qt.MouseButton.RightButton:
-            from calibre.gui2.ui import get_gui
-            gui = get_gui()
-            if self.icname == 'search':
-                gui.iactions['Preferences'].do_config(initial_plugin=('Interface', 'Search'), close_after_initial=True)
-                ev.accept()
-                return
-            tab_name = {'book':'book_details', 'grid':'cover_grid', 'cover_flow':'cover_browser',
-                        'tags':'tag_browser', 'quickview':'quickview'}.get(self.icname)
-            if tab_name:
-                if gui is not None:
-                    gui.iactions['Preferences'].do_config(initial_plugin=('Interface', 'Look & Feel', tab_name+'_tab'), close_after_initial=True)
-                    ev.accept()
-                    return
-        return QToolButton.mouseReleaseEvent(self, ev)
-
-
-class Splitter(QSplitter):
-
-    state_changed = pyqtSignal(object)
-    reapply_sizes = pyqtSignal(object)
-
-    def __init__(self, name, label, icon, initial_show=True,
-            initial_side_size=120, connect_button=True,
-            orientation=Qt.Orientation.Horizontal, side_index=0, parent=None,
-            shortcut=None, hide_handle_on_single_panel=True):
-        super().__init__(parent)
-        self.reapply_sizes.connect(self.setSizes, type=Qt.ConnectionType.QueuedConnection)
-        self.hide_handle_on_single_panel = hide_handle_on_single_panel
-        if hide_handle_on_single_panel:
-            self.state_changed.connect(self.update_handle_width)
-        self.original_handle_width = self.handleWidth()
-        self.resize_timer = QTimer(self)
-        self.resize_timer.setSingleShot(True)
-        self.desired_side_size = initial_side_size
-        self.desired_show = initial_show
-        self.resize_timer.setInterval(5)
-        self.resize_timer.timeout.connect(self.do_resize)
-        self.setOrientation(orientation)
-        self.side_index = side_index
-        self._name = name
-        self.label = label
-        self.initial_side_size = initial_side_size
-        self.initial_show = initial_show
-        self.splitterMoved.connect(self.splitter_moved, type=Qt.ConnectionType.QueuedConnection)
-        self.button = LayoutButton(icon, label, self, shortcut=shortcut)
-        if connect_button:
-            self.button.clicked.connect(self.double_clicked)
-
-        if shortcut is not None:
-            self.action_toggle = QAction(QIcon.ic(icon), _('Toggle') + ' ' + label,
-                    self)
-            self.action_toggle.changed.connect(self.update_shortcut)
-            self.action_toggle.triggered.connect(self.toggle_triggered)
-            if parent is not None:
-                parent.addAction(self.action_toggle)
-                if hasattr(parent, 'keyboard'):
-                    parent.keyboard.register_shortcut('splitter %s %s'%(name,
-                        label), str(self.action_toggle.text()),
-                        default_keys=(shortcut,), action=self.action_toggle)
-                else:
-                    self.action_toggle.setShortcut(shortcut)
-            else:
-                self.action_toggle.setShortcut(shortcut)
-
-    def update_shortcut(self):
-        self.button.update_shortcut(self.action_toggle)
-
-    def toggle_triggered(self, *args):
-        self.toggle_side_pane()
-
-    def createHandle(self):
-        return SplitterHandle(self.orientation(), self)
-
-    def initialize(self):
-        for i in range(self.count()):
-            h = self.handle(i)
-            if h is not None:
-                h.splitter_moved()
-        self.state_changed.emit(not self.is_side_index_hidden)
-
-    def splitter_moved(self, *args):
-        self.desired_side_size = self.side_index_size
-        self.state_changed.emit(not self.is_side_index_hidden)
-
-    def update_handle_width(self, not_one_panel):
-        self.setHandleWidth(self.original_handle_width if not_one_panel else 0)
-
-    @property
-    def is_side_index_hidden(self):
-        sizes = list(self.sizes())
-        try:
-            return sizes[self.side_index] == 0
-        except IndexError:
-            return True
-
-    @property
-    def save_name(self):
-        ori = 'horizontal' if self.orientation() == Qt.Orientation.Horizontal \
-                else 'vertical'
-        return self._name + '_' + ori
-
-    def print_sizes(self):
-        if self.count() > 1:
-            print(self.save_name, 'side:', self.side_index_size, 'other:', end=' ')
-            print(list(self.sizes())[self.other_index])
-
-    @property
-    def side_index_size(self):
-        if self.count() < 2:
-            return 0
-        return self.sizes()[self.side_index]
-
-    @side_index_size.setter
-    def side_index_size(self, val):
-        if self.count() < 2:
-            return
-        side_index_hidden = self.is_side_index_hidden
-        if val == 0 and not side_index_hidden:
-            self.save_state()
-        sizes = list(self.sizes())
-        for i in range(len(sizes)):
-            sizes[i] = val if i == self.side_index else 10
-        self.setSizes(sizes)
-        sizes = list(self.sizes())
-        total = sum(sizes)
-        total_needs_adjustment = self.hide_handle_on_single_panel and side_index_hidden
-        if total_needs_adjustment:
-            total -= self.original_handle_width
-        for i in range(len(sizes)):
-            sizes[i] = val if i == self.side_index else total-val
-        self.setSizes(sizes)
-        self.initialize()
-        if total_needs_adjustment:
-            # the handle visibility and therefore size distribution will change
-            # when the event loop ticks
-            self.reapply_sizes.emit(sizes)
-
-    def do_resize(self, *args):
-        orig = self.desired_side_size
-        super().resizeEvent(self._resize_ev)
-        if orig > 20 and self.desired_show:
-            c = 0
-            while abs(self.side_index_size - orig) > 10 and c < 5:
-                self.apply_state(self.get_state(), save_desired=False)
-                c += 1
-
-    def resizeEvent(self, ev):
-        if self.resize_timer.isActive():
-            self.resize_timer.stop()
-        self._resize_ev = ev
-        self.resize_timer.start()
-
-    def get_state(self):
-        if self.count() < 2:
-            return (False, 200)
-        return (self.desired_show, self.desired_side_size)
-
-    def apply_state(self, state, save_desired=True):
-        if state[0]:
-            self.side_index_size = state[1]
-            if save_desired:
-                self.desired_side_size = self.side_index_size
-        else:
-            self.side_index_size = 0
-        self.desired_show = state[0]
-
-    def default_state(self):
-        return (self.initial_show, self.initial_side_size)
-
-    # Public API {{{
-
-    def update_desired_state(self):
-        self.desired_show = not self.is_side_index_hidden
-
-    def save_state(self):
-        if self.count() > 1:
-            gprefs[self.save_name+'_state'] = self.get_state()
-
-    @property
-    def other_index(self):
-        return (self.side_index+1)%2
-
-    def restore_state(self):
-        if self.count() > 1:
-            state = gprefs.get(self.save_name+'_state',
-                    self.default_state())
-            self.apply_state(state, save_desired=False)
-            self.desired_side_size = state[1]
-
-    def toggle_side_pane(self, hide=None):
-        if hide is None:
-            action = 'show' if self.is_side_index_hidden else 'hide'
-        else:
-            action = 'hide' if hide else 'show'
-        getattr(self, action+'_side_pane')()
-
-    def show_side_pane(self):
-        if self.count() < 2 or not self.is_side_index_hidden:
-            return
-        if self.desired_side_size == 0:
-            self.desired_side_size = self.initial_side_size
-        self.apply_state((True, self.desired_side_size))
-
-    def hide_side_pane(self):
-        if self.count() < 2 or self.is_side_index_hidden:
-            return
-        self.apply_state((False, self.desired_side_size))
-
-    def double_clicked(self, *args):
-        self.toggle_side_pane()
-
-    # }}}
-
-# }}}
-
 
 class PaperSizes(QComboBox):  # {{{
 
