@@ -314,9 +314,10 @@ class BuildTest(unittest.TestCase):
         if is_sanitized:
             raise unittest.SkipTest('Skipping Qt build test as sanitizer is enabled')
         from qt.core import (
-            QApplication, QFontDatabase, QImageReader, QNetworkAccessManager,
-            QSslSocket, QTimer,
+            QApplication, QFontDatabase, QImageReader, QLoggingCategory,
+            QNetworkAccessManager, QSslSocket, QTimer,
         )
+        QLoggingCategory.setFilterRules('''qt.webenginecontext.debug=true''')
         from qt.webengine import QWebEnginePage
 
         from calibre.utils.img import image_from_data, image_to_data, test
@@ -373,7 +374,12 @@ class BuildTest(unittest.TestCase):
                 p.runJavaScript('1 + 1', callback)
                 p.printToPdf(print_callback)
 
+            def render_process_crashed(status, exit_code):
+                print('Qt WebEngine Render process crashed with status:', status, 'and exit code:', exit_code)
+                QApplication.instance().quit()
+
             p.titleChanged.connect(do_webengine_test)
+            p.renderProcessTerminated.connect(render_process_crashed)
             p.runJavaScript(f'document.title = "test-run-{os.getpid()}";')
             timeout = 10
             QTimer.singleShot(timeout * 1000, lambda: QApplication.instance().quit())
@@ -400,8 +406,8 @@ class BuildTest(unittest.TestCase):
         except ImportError:
             from PIL import _imaging, _imagingft, _imagingmath
         _imaging, _imagingmath, _imagingft
-        from PIL import features
         from io import StringIO
+        from PIL import features
         out = StringIO()
         features.pilinfo(out=out, supported_formats=False)
         out = out.getvalue()
@@ -505,6 +511,21 @@ class BuildTest(unittest.TestCase):
             cafile = ssl.get_default_verify_paths().cafile
             if not cafile or not cafile.endswith('/mozilla-ca-certs.pem') or not os.access(cafile, os.R_OK):
                 raise AssertionError('Mozilla CA certs not loaded')
+        # On Fedora create_default_context() succeeds in the main thread but
+        # not in other threads, because upstream OpenSSL cannot read whatever
+        # shit Fedora puts in /etc/ssl, so this check makes sure our bundled
+        # OpenSSL is built with ssl dir that is not /etc/ssl
+        from threading import Thread
+        certs_loaded = False
+        def check_ssl_loading_certs():
+            nonlocal certs_loaded
+            ssl.create_default_context()
+            certs_loaded = True
+        t = Thread(target=check_ssl_loading_certs)
+        t.start()
+        t.join()
+        if not certs_loaded:
+            raise AssertionError('Failed to load SSL certificates')
 
 
 def test_multiprocessing():
